@@ -66,13 +66,13 @@ class ConfiguredForm(models.Model):
             types = {type.key: type for type in sender.FORMS}
             sender.type = property(lambda self: import_if_string(types[self.form]))
 
-    def get_formfields_union(self, *, plugins, values=["name"], flat=True):
+    def get_formfields_union(self, *, plugins, values=["name"]):
         qs = None
         for plugin in plugins:
             if not issubclass(plugin, FormField):
                 continue
             plugin_qs = plugin.objects.filter(parent=self).values_list(
-                *values, flat=flat
+                *values, flat=len(values) == 1
             )
             if qs is None:
                 qs = plugin_qs
@@ -136,6 +136,15 @@ class FormField(models.Model):
         kwargs.setdefault("help_text", self.help_text)
         return {self.name: form_class(**kwargs)}
 
+    def get_loaders(self):
+        return [
+            lambda data: {
+                "label": self.label,
+                "name": self.name,
+                "value": data.get(self.name),
+            }
+        ]
+
 
 class SimpleFieldBase(FormField):
     class Type(models.TextChoices):
